# smart_analytica

**smart_analytica** is a Python library that lets you view Sigma Computing iframes **directly from Python** — no need to copy-paste HTML code! Works in **Jupyter Notebooks**, **scripts**, and **CLI**.

## Installation

```bash
pip install smart_analytica